==> mx-locale_24.5.02.tar.xz: BUILD/translations/mx-locale_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nome_do_Programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <source>System Locale</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation type="vanished">Idioma do Sistema Operacional</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>PushButton</source>
        <translation>Pressionar o Botão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Current System Language:</source>
        <translation>Idioma Atual do Sistema Operacional:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>System Language</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>Set all locale categories to current language</source>
        <translation>Definir todas as categorias da localidade para o idioma atual</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Locale Categories</source>
        <extracomment>defines individual subvariables for locale</extracomment>
        <translation>Categorias Locais</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Numeric</source>
        <translation>Numérico</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Time</source>
        <translation>Horário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Collate</source>
        <translation>Agrupar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Currency</source>
        <translation>Moeda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Messages</source>
        <translation>Mensagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Paper Size</source>
        <translation>Tamanho do Papel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Name Style</source>
        <translation>Estilo de Nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Telephone</source>
        <translation>Telefone</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Measurement</source>
        <translation>Unidade de Medida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Locale Management</source>
        <extracomment>Tab to manage generation of locale caches</extracomment>
        <translation>Gerenciamento da Localidade</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <location filename="../mainwindow.ui" line="469"/>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>All</source>
        <extracomment>elements of filter box</extracomment>
        <translation>Todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Enabled</source>
        <translation>Ativado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Disable all locales except the one in use</source>
        <extracomment>disables generation of any locale except on that is currently in use</extracomment>
        <translation>Desativar todas as localidades, exceto aquela que está sendo utilizada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Reset locale list to default</source>
        <translation>Redefinir a lista de localidades para o padrão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>Remover os manuais do MX dos idiomas diferentes do padrão do sistema operacional</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Changes go into effect on login</source>
        <translation>As alterações entrarão em vigor na próxima vez que você iniciar a sessão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Locale</source>
        <translation>Configurações de Idioma do Sistema Operacional</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Program for changing language and locale categories</source>
        <translation>O ‘MX Locale’ permite definir o idioma e os padrões das categorias referentes ao local ou região, como por exemplo, horário, moeda, numérico, tamanho do papel, etc.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="149"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Locale in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <comment>shows the current system locale, in bold</comment>
        <translation>Idioma em uso: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>All</source>
        <comment>all as in everything</comment>
        <translation>Todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Error</source>
        <translation>Ocorreu um erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>Can&apos;t disable locale in use</source>
        <comment>message that the chosen locale cannot be disabled because it is in active usage</comment>
        <translation>Não é possível desativar as configurações locais que estão sendo utilizadas neste momento</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Locales enabled: %1</source>
        <comment>label for a numerical count of enabled and available locales</comment>
        <translation>Locais ativados: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Could not open %1</source>
        <translation>Não foi possível abrir %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Locales enabled: %1</source>
        <translation>Locais ativados: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Updating locales, please wait</source>
        <translation>Atualizando as traduções. Por favor, aguarde a finalização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Removing packages, please wait</source>
        <translation>Removendo os pacotes. Por favor, aguarde a finalização</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="36"/>
        <location filename="../about.cpp" line="46"/>
        <source>Changelog</source>
        <translation>Relatório de Alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>MX Locale is a tool used for managing locale settings in MX Linux</source>
        <translation>O ‘MX Locale’ permite definir o idioma e os padrões das categorias referentes ao local ou região, como por exemplo, horário, moeda, numérico, tamanho do papel, etc.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Show only language selection tab.</source>
        <translation>Exibir apenas a aba ou guia de seleção do idioma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Show all locale categories.</source>
        <translation>Exibir todas as categorias locais.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <location filename="../main.cpp" line="79"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Ao que parece, você está acessando a sessão atual com o usuário ‘root’ (administrador). Por favor, saia da sessão atual e entre novamente com o usuário normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You must run this program with admin access.</source>
        <translation>Você tem que executar este programa com o usuário administrador.</translation>
    </message>
</context>
<context>
    <name>chooseDialog</name>
    <message>
        <location filename="../choosedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Janela de Diálogo</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="48"/>
        <source>search</source>
        <translation>Digite aqui para pesquisar</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="58"/>
        <source>If your desired language is not listed here, enable it in &quot;Locale management&quot; tab</source>
        <translation>Se o idioma que você quer não estiver listado aqui, por favor, ative-o na aba ‘Gerenciamento da Localidade’</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="25"/>
        <source>MX Locale</source>
        <comment>name of application</comment>
        <translation>Configurações de Idioma e da Localidade do Sistema Operacional</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="40"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="41"/>
        <source>Could not open %1</source>
        <comment>message that a file could not be open, file takes place of %1</comment>
        <translation>Não foi possível abrir %1</translation>
    </message>
</context>
</TS>

==> mx-locale_25.4.tar.xz: BUILD/translations/mx-locale_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nome_do_Programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>PushButton</source>
        <translation>Pressionar o Botão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Current System Language:</source>
        <translation>Idioma Atual do Sistema Operacional:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>System Language</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation>Configurações de Idioma do Sistema Operacional</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>Set all locale categories to current language</source>
        <translation>Definir todas as categorias da localidade para o idioma atual</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Locale Categories</source>
        <extracomment>defines individual subvariables for locale</extracomment>
        <translation>Categorias Locais</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Numeric</source>
        <translation>Numérico</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Time</source>
        <translation>Horário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Collate</source>
        <translation>Agrupar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Currency</source>
        <translation>Moeda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Messages</source>
        <translation>Mensagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Paper Size</source>
        <translation>Tamanho do Papel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Name Style</source>
        <translation>Estilo de Nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Telephone</source>
        <translation>Telefone</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Measurement</source>
        <translation>Unidade de Medida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Locale Management</source>
        <extracomment>Tab to manage generation of locale caches</extracomment>
        <translation>Gerenciamento da Localidade</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <location filename="../mainwindow.ui" line="469"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>All</source>
        <extracomment>elements of filter box</extracomment>
        <translation>Todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Enabled</source>
        <translation>Ativado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Disable all locales except the one in use</source>
        <extracomment>disables generation of any locale except on that is currently in use</extracomment>
        <translation>Desativar todas as localidades, exceto aquela que está sendo utilizada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Reset locale list to default</source>
        <translation>Redefinir a lista de localidades para o padrão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>Remover os manuais do MX dos idiomas diferentes do padrão do sistema operacional</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Changes go into effect on login</source>
        <translation>As alterações entrarão em vigor na próxima vez que você iniciar a sessão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>MX Locale</source>
        <translation>Configurações de Idioma do Sistema Operacional</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="153"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="156"/>
        <source>Program for changing language and locale categories</source>
        <translation>O ‘MX Locale’ permite definir o idioma e os padrões das categorias referentes ao local ou região, como por exemplo, horário, moeda, numérico, tamanho do papel, etc.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Locale in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <comment>shows the current system locale, in bold</comment>
        <translation>Idioma em uso: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>All</source>
        <comment>all as in everything</comment>
        <translation>Todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <location filename="../mainwindow.cpp" line="375"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Error</source>
        <translation>Ocorreu um erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Can&apos;t disable locale in use</source>
        <comment>message that the chosen locale cannot be disabled because it is in active usage</comment>
        <translation>Não é possível desativar as configurações locais que estão sendo utilizadas neste momento</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="350"/>
        <source>Locales enabled: %1</source>
        <comment>label for a numerical count of enabled and available locales</comment>
        <translation>Locais ativados: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Could not open %1</source>
        <translation>Não foi possível abrir %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Locales enabled: %1</source>
        <translation>Locais ativados: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Updating locales, please wait</source>
        <translation>Atualizando as traduções. Por favor, aguarde a finalização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Remove Manuals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>No manuals to remove.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Removing packages, please wait</source>
        <translation>Removendo os pacotes. Por favor, aguarde a finalização</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Relatório de Alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>MX Locale is a tool used for managing locale settings in MX Linux</source>
        <translation>O ‘MX Locale’ permite definir o idioma e os padrões das categorias referentes ao local ou região, como por exemplo, horário, moeda, numérico, tamanho do papel, etc.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Show only language selection tab.</source>
        <translation>Exibir apenas a aba ou guia de seleção do idioma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Show all locale categories.</source>
        <translation>Exibir todas as categorias locais.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <location filename="../main.cpp" line="90"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Ao que parece, você está acessando a sessão atual com o usuário ‘root’ (administrador). Por favor, saia da sessão atual e entre novamente com o usuário normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>You must run this program with admin access.</source>
        <translation>Você tem que executar este programa com o usuário administrador.</translation>
    </message>
</context>
<context>
    <name>chooseDialog</name>
    <message>
        <location filename="../choosedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Janela de Diálogo</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="48"/>
        <source>search</source>
        <translation>Digite aqui para pesquisar</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="58"/>
        <source>If your desired language is not listed here, enable it in &quot;Locale management&quot; tab</source>
        <translation>Se o idioma que você quer não estiver listado aqui, por favor, ative-o na aba ‘Gerenciamento da Localidade’</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="25"/>
        <source>MX Locale</source>
        <comment>name of application</comment>
        <translation>Configurações de Idioma e da Localidade do Sistema Operacional</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="40"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="41"/>
        <source>Could not open %1</source>
        <comment>message that a file could not be opened, file takes place of %1</comment>
        <translation type="unfinished">Não foi possível abrir %1</translation>
    </message>
    <message>
        <source>Could not open %1</source>
        <comment>message that a file could not be open, file takes place of %1</comment>
        <translation type="vanished">Não foi possível abrir %1</translation>
    </message>
</context>
</TS>
